using System;

namespace Jauchdiplom
{
	/// <summary>
	/// Class Question is the base type for any kind of quiz specific question.
	/// </summary>
	public class Question
	{
		public Question( string a_task )
		{
			task = a_task;
		}

		private string task;

		public string Task 
		{
			get 
			{
				return task;
			}
		}

	}

	/// <summary>
	/// MultipleChoice is the basic type of questions supported by the system.
	/// </summary>
	public class MultipleChoice : Question 
	{
		public MultipleChoice ( string a_task, string [] a_answers, int a_correct ) : base(a_task) 
		{
			answers = a_answers;
			correct = a_correct;
		}

		private string [] answers;
		private int correct;

		public string Answer ( int i ) 
		{
			return answers[i];
		}

		public int CorrectAnswer 
		{
			get 
			{
				return correct;
			}
		}
	}


	/// <summary>
	/// Stores student-specific state information. Most tutor's will need to store additional information for
	/// individual students. A appropriate data structure is needed to capture this information dynamically without
	/// the need to re-structure the whole system.
	/// </summary>
	public class Student 
	{
		public Student ( string a_name ) 
		{
			name = a_name;
		}

		private string name;

		public string Name 
		{
			get 
			{
				return name;
			}
		}
	}


	public abstract class UI 
	{
		public abstract int PresentMultipleChoice ( MultipleChoice mc );
		public abstract void TutorComment ( string comment );
	}

	public abstract class QuestionDB
	{
		public abstract Question NextQuestion ();
	}

}
